Michel is your friendly mate that helps you managing your todo list. It
can push/pull flat text files to google tasks.

Keeping it stupid simple
========================

Michel has only two commands:

    michel pull
which prints the default todo list on the standard output

    michel push <TODO.txt>
which replaces the default todo list with the content of TODO.txt

Non features
------------

Michel aims at being simple: it does not handle due dates nor notes.

Syntax
------

One line is one task. Indented lines are subtasks of the "parent" line.

Installing
==========

Author/License
==============

- Original author: Christophe-Marie Duquesne
- License: Public Domain
